/* eslint-disable */
import * as types from './graphql';
import { TypedDocumentNode as DocumentNode } from '@graphql-typed-document-node/core';

/**
 * Map of all GraphQL operations in the project.
 *
 * This map has several performance disadvantages:
 * 1. It is not tree-shakeable, so it will include all operations in the project.
 * 2. It is not minifiable, so the string of a GraphQL query will be multiple times inside the bundle.
 * 3. It does not support dead code elimination, so it will add unused operations.
 *
 * Therefore it is highly recommended to use the babel or swc plugin for production.
 */
const documents = {
    "\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    lead\n    body {\n      ...Blocks\n    }\n  }\n": types.GenericFragmentDoc,
    "\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  ": types.AllGenericSlugsDocument,
    "\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  ": types.GenericPageByUrlDocument,
    "\n    query allNewsSlugs {\n      pages(contentType: \"news.NewsPage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllNewsSlugsDocument,
    "\n    query newsBySlug($slug: String!) {\n      news: page(contentType: \"news.NewsPage\", slug: $slug) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  ": types.NewsBySlugDocument,
    "\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllEventSlugsDocument,
    "\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  ": types.EventBySlugDocument,
    "\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllAssociationSlugsDocument,
    "\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  ": types.AssociationBySlugDocument,
    "\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n": types.AssociationIndexFragmentDoc,
    "\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    excerpt\n    body {\n      ...Blocks\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n": types.AssociationFragmentDoc,
    "\n    query allAssociations {\n      index: associationIndex {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  ": types.AllAssociationsDocument,
    "\n  fragment ContactIndex on ContactIndex {\n    ... on ContactIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n": types.ContactIndexFragmentDoc,
    "\n    query contacts {\n      contactIndex {\n        ... on ContactIndex {\n          ...ContactIndex\n        }\n      }\n    }\n  ": types.ContactsDocument,
    "\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  ": types.AllVenueSlugsDocument,
    "\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  ": types.VenueBySlugDocument,
    "\n  fragment VenueIndex on VenueIndex {\n    ... on VenueIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n": types.VenueIndexFragmentDoc,
    "\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      ...Blocks\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n": types.VenueFragmentDoc,
    "\n    query venueIndex {\n      index: venueIndex {\n        ... on VenueIndex {\n          ...VenueIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  ": types.VenueIndexDocument,
    "\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n": types.HomeFragmentDoc,
    "\n    query home {\n      events: eventIndex {\n        ... on EventIndex {\n          futureEvents {\n            ... on EventPage {\n              ...Event\n            }\n          }\n        }\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n      news: pages(contentType: \"news.newsPage\", order: \"-first_published_at\", limit: 4) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  ": types.HomeDocument,
    "\n      query search($query: String) {\n        results: search(query: $query) {\n          __typename\n          ... on NewsPage {\n            id\n            title\n          }\n          ... on EventPage {\n            id\n            title\n          }\n          ... on GenericPage {\n            id\n            title\n          }\n          ... on VenuePage {\n            id\n            title\n          }\n          ... on AssociationPage {\n            id\n            title\n            associationType\n          }\n        }\n      }\n    ": types.SearchDocument,
    "\n  fragment VenueRentalIndex on VenueRentalIndex {\n    ... on VenueRentalIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n": types.VenueRentalIndexFragmentDoc,
    "\n    query venueRentalIndex {\n      index: venueRentalIndex {\n        ... on VenueRentalIndex {\n          ...VenueRentalIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  ": types.VenueRentalIndexDocument,
    "\n  fragment OneLevelOfBlocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n    ... on HorizontalRuleBlock {\n      color\n    }\n    ... on FeaturedBlock {\n      title\n      featuredBlockText: text\n      linkText\n      imagePosition\n      backgroundColor\n      featuredPage {\n        contentType\n        pageType\n        url\n        ... on EventPage {\n          featuredImage {\n            ...Image\n          }\n        }\n        ... on NewsPage {\n          featuredImage {\n            ...Image\n          }\n        }\n      }\n      featuredImageOverride {\n        ...Image\n      }\n    }\n    ... on ContactListBlock {\n      items {\n        blockType\n        ... on ContactEntityBlock {\n          contactEntity {\n            ...ContactEntity\n          }\n        }\n      }\n    }\n    ... on EmbedBlock {\n      url\n      embed\n      rawEmbed\n    }\n  }\n": types.OneLevelOfBlocksFragmentDoc,
    "\n  fragment Blocks on StreamFieldInterface {\n    ... on AccordionBlock {\n      heading\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on FactBoxBlock {\n      heading\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on PageSectionBlock {\n      title\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on ContactSectionBlock {\n      title\n      text\n      blocks {\n        ... on ContactSubsectionBlock {\n          title\n          text\n          blocks {\n            ...OneLevelOfBlocks\n          }\n        }\n        ...OneLevelOfBlocks\n      }\n    }\n    ...OneLevelOfBlocks\n  }\n": types.BlocksFragmentDoc,
    "\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n": types.ImageFragmentDoc,
    "\n  fragment ContactEntity on ContactEntity {\n    id\n    name\n    contactType\n    title\n    email\n    phoneNumber\n    image {\n      ...Image\n    }\n  }\n": types.ContactEntityFragmentDoc,
    "\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    pig\n    facebookUrl\n    ticketUrl\n    free\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n        pig\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n          preposition\n          url\n        }\n      }\n    }\n    organizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n  }\n": types.EventFragmentDoc,
    "\n  query futureEvents {\n    events: eventIndex {\n      ... on EventIndex {\n        futureEvents {\n          ... on EventPage {\n            ...Event\n          }\n        }\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n    eventOrganizers: eventOrganizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n    venues: pages(contentType: \"venues.VenuePage\") {\n      ... on VenuePage {\n        id\n        title\n        slug\n        preposition\n      }\n    }\n  }\n": types.FutureEventsDocument,
    "\n  fragment News on NewsPage {\n    __typename\n    id\n    slug\n    title\n    firstPublishedAt\n    excerpt\n    lead\n    featuredImage {\n      ...Image\n    }\n    body {\n      ...Blocks\n    }\n  }\n": types.NewsFragmentDoc,
    "\n  fragment NewsIndex on NewsIndex {\n    __typename\n    id\n    slug\n    title\n    lead\n  }\n": types.NewsIndexFragmentDoc,
    "\n  query news {\n    index: newsIndex {\n      ... on NewsIndex {\n        ...NewsIndex\n      }\n    }\n    news: pages(contentType: \"news.NewsPage\", order: \"-first_published_at\") {\n      ... on NewsPage {\n        ...News\n      }\n    }\n  }\n": types.NewsDocument,
    "\n  query openingHoursSets {\n    openingHoursSets {\n      ...OpeningHoursSetFragment\n    }\n  }\n": types.OpeningHoursSetsDocument,
    "\n  fragment OpeningHoursSetFragment on OpeningHoursSet {\n    name\n    effectiveFrom\n    effectiveTo\n    announcement\n    items {\n      id\n      function\n      week {\n        id\n        blockType\n        ... on OpeningHoursWeekBlock {\n          ...OpeningHoursWeekBlock\n        }\n      }\n    }\n  }\n": types.OpeningHoursSetFragmentFragmentDoc,
    "\n  fragment OpeningHoursRangeBlock on OpeningHoursRangeBlock {\n    timeFrom\n    timeTo\n    custom\n  }\n": types.OpeningHoursRangeBlockFragmentDoc,
    "\n  fragment OpeningHoursWeekBlock on OpeningHoursWeekBlock {\n    monday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    tuesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    wednesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    thursday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    friday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    saturday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    sunday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n  }\n": types.OpeningHoursWeekBlockFragmentDoc,
};

/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 *
 *
 * @example
 * ```ts
 * const query = graphql(`query GetUser($id: ID!) { user(id: $id) { name } }`);
 * ```
 *
 * The query argument is unknown!
 * Please regenerate the types.
 */
export function graphql(source: string): unknown;

/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    lead\n    body {\n      ...Blocks\n    }\n  }\n"): (typeof documents)["\n  fragment Generic on GenericPage {\n    __typename\n    id\n    urlPath\n    title\n    lead\n    body {\n      ...Blocks\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  "): (typeof documents)["\n    query allGenericSlugs {\n      pages(contentType: \"generic.GenericPage\") {\n        id\n        urlPath\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  "): (typeof documents)["\n    query genericPageByUrl($urlPath: String!) {\n      page: page(contentType: \"generic.GenericPage\", urlPath: $urlPath) {\n        ... on GenericPage {\n          ...Generic\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allNewsSlugs {\n      pages(contentType: \"news.NewsPage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allNewsSlugs {\n      pages(contentType: \"news.NewsPage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query newsBySlug($slug: String!) {\n      news: page(contentType: \"news.NewsPage\", slug: $slug) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  "): (typeof documents)["\n    query newsBySlug($slug: String!) {\n      news: page(contentType: \"news.NewsPage\", slug: $slug) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allEventSlugs {\n      pages(contentType: \"events.EventPage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  "): (typeof documents)["\n    query eventBySlug($slug: String!) {\n      event: page(contentType: \"events.EventPage\", slug: $slug) {\n        ... on EventPage {\n          ...Event\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allAssociationSlugs {\n      pages(contentType: \"associations.AssociationPage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "): (typeof documents)["\n    query associationBySlug($slug: String!) {\n      association: page(\n        contentType: \"associations.AssociationPage\"\n        slug: $slug\n      ) {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment AssociationIndex on AssociationIndex {\n    ... on AssociationIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    excerpt\n    body {\n      ...Blocks\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n"): (typeof documents)["\n  fragment Association on AssociationPage {\n    __typename\n    id\n    slug\n    title\n    excerpt\n    body {\n      ...Blocks\n    }\n    logo {\n      url\n      width\n      height\n    }\n    associationType\n    websiteUrl\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allAssociations {\n      index: associationIndex {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "): (typeof documents)["\n    query allAssociations {\n      index: associationIndex {\n        ... on AssociationIndex {\n          ...AssociationIndex\n        }\n      }\n      associations: pages(contentType: \"associations.AssociationPage\") {\n        ... on AssociationPage {\n          ...Association\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment ContactIndex on ContactIndex {\n    ... on ContactIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment ContactIndex on ContactIndex {\n    ... on ContactIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query contacts {\n      contactIndex {\n        ... on ContactIndex {\n          ...ContactIndex\n        }\n      }\n    }\n  "): (typeof documents)["\n    query contacts {\n      contactIndex {\n        ... on ContactIndex {\n          ...ContactIndex\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  "): (typeof documents)["\n    query allVenueSlugs {\n      pages(contentType: \"venues.VenuePage\") {\n        id\n        slug\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "): (typeof documents)["\n    query venueBySlug($slug: String!) {\n      venue: page(contentType: \"venues.VenuePage\", slug: $slug) {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment VenueIndex on VenueIndex {\n    ... on VenueIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment VenueIndex on VenueIndex {\n    ... on VenueIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      ...Blocks\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n"): (typeof documents)["\n  fragment Venue on VenuePage {\n    __typename\n    id\n    slug\n    title\n    body {\n      ...Blocks\n    }\n    featuredImage {\n      ...Image\n    }\n    showAsBookable\n    floor\n    preposition\n    capabilityAudio\n    capabilityAudioVideo\n    capabilityBar\n    capabilityLighting\n    capacityLegal\n    capacityStanding\n    capacitySitting\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query venueIndex {\n      index: venueIndex {\n        ... on VenueIndex {\n          ...VenueIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "): (typeof documents)["\n    query venueIndex {\n      index: venueIndex {\n        ... on VenueIndex {\n          ...VenueIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment Home on HomePage {\n    ... on HomePage {\n      featuredEvents {\n        id\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query home {\n      events: eventIndex {\n        ... on EventIndex {\n          futureEvents {\n            ... on EventPage {\n              ...Event\n            }\n          }\n        }\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n      news: pages(contentType: \"news.newsPage\", order: \"-first_published_at\", limit: 4) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  "): (typeof documents)["\n    query home {\n      events: eventIndex {\n        ... on EventIndex {\n          futureEvents {\n            ... on EventPage {\n              ...Event\n            }\n          }\n        }\n      }\n      home: page(contentType: \"home.HomePage\", urlPath: \"/home/\") {\n        ... on HomePage {\n          ...Home\n        }\n      }\n      news: pages(contentType: \"news.newsPage\", order: \"-first_published_at\", limit: 4) {\n        ... on NewsPage {\n          ...News\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n      query search($query: String) {\n        results: search(query: $query) {\n          __typename\n          ... on NewsPage {\n            id\n            title\n          }\n          ... on EventPage {\n            id\n            title\n          }\n          ... on GenericPage {\n            id\n            title\n          }\n          ... on VenuePage {\n            id\n            title\n          }\n          ... on AssociationPage {\n            id\n            title\n            associationType\n          }\n        }\n      }\n    "): (typeof documents)["\n      query search($query: String) {\n        results: search(query: $query) {\n          __typename\n          ... on NewsPage {\n            id\n            title\n          }\n          ... on EventPage {\n            id\n            title\n          }\n          ... on GenericPage {\n            id\n            title\n          }\n          ... on VenuePage {\n            id\n            title\n          }\n          ... on AssociationPage {\n            id\n            title\n            associationType\n          }\n        }\n      }\n    "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment VenueRentalIndex on VenueRentalIndex {\n    ... on VenueRentalIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment VenueRentalIndex on VenueRentalIndex {\n    ... on VenueRentalIndex {\n      title\n      lead\n      body {\n        ...Blocks\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n    query venueRentalIndex {\n      index: venueRentalIndex {\n        ... on VenueRentalIndex {\n          ...VenueRentalIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "): (typeof documents)["\n    query venueRentalIndex {\n      index: venueRentalIndex {\n        ... on VenueRentalIndex {\n          ...VenueRentalIndex\n        }\n      }\n      venues: pages(contentType: \"venues.VenuePage\") {\n        ... on VenuePage {\n          ...Venue\n        }\n      }\n    }\n  "];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment OneLevelOfBlocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n    ... on HorizontalRuleBlock {\n      color\n    }\n    ... on FeaturedBlock {\n      title\n      featuredBlockText: text\n      linkText\n      imagePosition\n      backgroundColor\n      featuredPage {\n        contentType\n        pageType\n        url\n        ... on EventPage {\n          featuredImage {\n            ...Image\n          }\n        }\n        ... on NewsPage {\n          featuredImage {\n            ...Image\n          }\n        }\n      }\n      featuredImageOverride {\n        ...Image\n      }\n    }\n    ... on ContactListBlock {\n      items {\n        blockType\n        ... on ContactEntityBlock {\n          contactEntity {\n            ...ContactEntity\n          }\n        }\n      }\n    }\n    ... on EmbedBlock {\n      url\n      embed\n      rawEmbed\n    }\n  }\n"): (typeof documents)["\n  fragment OneLevelOfBlocks on StreamFieldInterface {\n    id\n    blockType\n    field\n    ... on RichTextBlock {\n      rawValue\n      value\n    }\n    ... on ImageWithTextBlock {\n      image {\n        ...Image\n      }\n      imageFormat\n      text\n    }\n    ... on ImageSliderBlock {\n      images {\n        ... on ImageSliderItemBlock {\n          image {\n            ...Image\n          }\n          text\n        }\n      }\n    }\n    ... on HorizontalRuleBlock {\n      color\n    }\n    ... on FeaturedBlock {\n      title\n      featuredBlockText: text\n      linkText\n      imagePosition\n      backgroundColor\n      featuredPage {\n        contentType\n        pageType\n        url\n        ... on EventPage {\n          featuredImage {\n            ...Image\n          }\n        }\n        ... on NewsPage {\n          featuredImage {\n            ...Image\n          }\n        }\n      }\n      featuredImageOverride {\n        ...Image\n      }\n    }\n    ... on ContactListBlock {\n      items {\n        blockType\n        ... on ContactEntityBlock {\n          contactEntity {\n            ...ContactEntity\n          }\n        }\n      }\n    }\n    ... on EmbedBlock {\n      url\n      embed\n      rawEmbed\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Blocks on StreamFieldInterface {\n    ... on AccordionBlock {\n      heading\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on FactBoxBlock {\n      heading\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on PageSectionBlock {\n      title\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on ContactSectionBlock {\n      title\n      text\n      blocks {\n        ... on ContactSubsectionBlock {\n          title\n          text\n          blocks {\n            ...OneLevelOfBlocks\n          }\n        }\n        ...OneLevelOfBlocks\n      }\n    }\n    ...OneLevelOfBlocks\n  }\n"): (typeof documents)["\n  fragment Blocks on StreamFieldInterface {\n    ... on AccordionBlock {\n      heading\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on FactBoxBlock {\n      heading\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on PageSectionBlock {\n      title\n      backgroundColor\n      body {\n        ...OneLevelOfBlocks\n      }\n    }\n    ... on ContactSectionBlock {\n      title\n      text\n      blocks {\n        ... on ContactSubsectionBlock {\n          title\n          text\n          blocks {\n            ...OneLevelOfBlocks\n          }\n        }\n        ...OneLevelOfBlocks\n      }\n    }\n    ...OneLevelOfBlocks\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n"): (typeof documents)["\n  fragment Image on CustomImage {\n    id\n    url\n    width\n    height\n    alt\n    attribution\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment ContactEntity on ContactEntity {\n    id\n    name\n    contactType\n    title\n    email\n    phoneNumber\n    image {\n      ...Image\n    }\n  }\n"): (typeof documents)["\n  fragment ContactEntity on ContactEntity {\n    id\n    name\n    contactType\n    title\n    email\n    phoneNumber\n    image {\n      ...Image\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    pig\n    facebookUrl\n    ticketUrl\n    free\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n        pig\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n          preposition\n          url\n        }\n      }\n    }\n    organizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment Event on EventPage {\n    __typename\n    id\n    slug\n    title\n    body {\n      id\n      blockType\n      field\n      ... on RichTextBlock {\n        rawValue\n        value\n      }\n    }\n    featuredImage {\n      ...Image\n    }\n    pig\n    facebookUrl\n    ticketUrl\n    free\n    priceRegular\n    priceMember\n    priceStudent\n    categories {\n      ... on EventCategory {\n        name\n        slug\n        pig\n      }\n    }\n    occurrences {\n      ... on EventOccurrence {\n        __typename\n        id\n        start\n        end\n        venue {\n          __typename\n          id\n          slug\n          title\n          preposition\n          url\n        }\n      }\n    }\n    organizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  query futureEvents {\n    events: eventIndex {\n      ... on EventIndex {\n        futureEvents {\n          ... on EventPage {\n            ...Event\n          }\n        }\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n    eventOrganizers: eventOrganizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n    venues: pages(contentType: \"venues.VenuePage\") {\n      ... on VenuePage {\n        id\n        title\n        slug\n        preposition\n      }\n    }\n  }\n"): (typeof documents)["\n  query futureEvents {\n    events: eventIndex {\n      ... on EventIndex {\n        futureEvents {\n          ... on EventPage {\n            ...Event\n          }\n        }\n      }\n    }\n    eventCategories: eventCategories {\n      ... on EventCategory {\n        name\n        slug\n        showInFilters\n      }\n    }\n    eventOrganizers: eventOrganizers {\n      ... on EventOrganizer {\n        id\n        name\n        slug\n        externalUrl\n        association {\n          ... on AssociationPage {\n            url\n          }\n        }\n      }\n    }\n    venues: pages(contentType: \"venues.VenuePage\") {\n      ... on VenuePage {\n        id\n        title\n        slug\n        preposition\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment News on NewsPage {\n    __typename\n    id\n    slug\n    title\n    firstPublishedAt\n    excerpt\n    lead\n    featuredImage {\n      ...Image\n    }\n    body {\n      ...Blocks\n    }\n  }\n"): (typeof documents)["\n  fragment News on NewsPage {\n    __typename\n    id\n    slug\n    title\n    firstPublishedAt\n    excerpt\n    lead\n    featuredImage {\n      ...Image\n    }\n    body {\n      ...Blocks\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment NewsIndex on NewsIndex {\n    __typename\n    id\n    slug\n    title\n    lead\n  }\n"): (typeof documents)["\n  fragment NewsIndex on NewsIndex {\n    __typename\n    id\n    slug\n    title\n    lead\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  query news {\n    index: newsIndex {\n      ... on NewsIndex {\n        ...NewsIndex\n      }\n    }\n    news: pages(contentType: \"news.NewsPage\", order: \"-first_published_at\") {\n      ... on NewsPage {\n        ...News\n      }\n    }\n  }\n"): (typeof documents)["\n  query news {\n    index: newsIndex {\n      ... on NewsIndex {\n        ...NewsIndex\n      }\n    }\n    news: pages(contentType: \"news.NewsPage\", order: \"-first_published_at\") {\n      ... on NewsPage {\n        ...News\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  query openingHoursSets {\n    openingHoursSets {\n      ...OpeningHoursSetFragment\n    }\n  }\n"): (typeof documents)["\n  query openingHoursSets {\n    openingHoursSets {\n      ...OpeningHoursSetFragment\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment OpeningHoursSetFragment on OpeningHoursSet {\n    name\n    effectiveFrom\n    effectiveTo\n    announcement\n    items {\n      id\n      function\n      week {\n        id\n        blockType\n        ... on OpeningHoursWeekBlock {\n          ...OpeningHoursWeekBlock\n        }\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment OpeningHoursSetFragment on OpeningHoursSet {\n    name\n    effectiveFrom\n    effectiveTo\n    announcement\n    items {\n      id\n      function\n      week {\n        id\n        blockType\n        ... on OpeningHoursWeekBlock {\n          ...OpeningHoursWeekBlock\n        }\n      }\n    }\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment OpeningHoursRangeBlock on OpeningHoursRangeBlock {\n    timeFrom\n    timeTo\n    custom\n  }\n"): (typeof documents)["\n  fragment OpeningHoursRangeBlock on OpeningHoursRangeBlock {\n    timeFrom\n    timeTo\n    custom\n  }\n"];
/**
 * The graphql function is used to parse GraphQL queries into a document that can be used by GraphQL clients.
 */
export function graphql(source: "\n  fragment OpeningHoursWeekBlock on OpeningHoursWeekBlock {\n    monday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    tuesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    wednesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    thursday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    friday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    saturday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    sunday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n  }\n"): (typeof documents)["\n  fragment OpeningHoursWeekBlock on OpeningHoursWeekBlock {\n    monday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    tuesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    wednesday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    thursday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    friday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    saturday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n    sunday {\n      ... on OpeningHoursRangeBlock {\n        ...OpeningHoursRangeBlock\n      }\n    }\n  }\n"];

export function graphql(source: string) {
  return (documents as any)[source] ?? {};
}

export type DocumentType<TDocumentNode extends DocumentNode<any, any>> = TDocumentNode extends DocumentNode<  infer TType,  any>  ? TType  : never;